@@ -3,14 +3,14 @@ use warnings;
 use 5.010;
 
 package JIRA::Client::Automated;
-$JIRA::Client::Automated::VERSION = '1.3';
+$JIRA::Client::Automated::VERSION = '1.4';
 =head1 NAME
 
 JIRA::Client::Automated - A JIRA REST Client for automated scripts
 
 =head1 VERSION
 
-version 1.3
+version 1.4
 
 =head1 SYNOPSIS
 
@@ -18,6 +18,9 @@ version 1.3
 
     my $jira = JIRA::Client::Automated->new($url, $user, $password);
 
+    # If your JIRA instance does not use username/password for authorization 
+    my $jira = JIRA::Client::Automated->new($url);
+
     my $jira_ua = $jira->ua(); # to add in a proxy
 
     $jira->trace(1); # enable tracing of requests and responses
@@ -164,7 +167,8 @@ Password for that user
 
 =back
 
-All three parameters are required. JIRA::Client::Automated must connect to the
+All three parameters are required if your JIRA instance uses basic
+authorization, for which JIRA::Client::Automated must connect to the
 JIRA instance using I<some> username and password. You may want to set up a
 special "auto" or "batch" username to use just for use by scripts.
 
@@ -172,13 +176,22 @@ If you are using Google Account integration, the username and password to use
 are the ones you set up at the very beginning of the registration process and
 then never used again because Google logged you in.
 
+If you have other ways of authorization, like GSSAPI based authorization, do
+not provide username or password. 
+
+    my $jira = JIRA::Client::Automated->new($url);
+
 =cut
 
 sub new {
     my ($class, $url, $user, $password) = @_;
 
-    unless (defined $url && $url && defined $user && $user && defined $password && $password) {
-        croak "Need to specify url, username, and password to access JIRA";
+    unless (defined $url && $url) {
+        croak "Need to specify url to access JIRA";
+    }
+    my $no_user_pwd = !(defined $user || defined $password);
+    unless ($no_user_pwd || defined $user && $user && defined $password && $password) {
+        croak "Need to either specify both user and password, or provide none of them";
     }
 
     unless ($url =~ m{/$}) {
@@ -269,7 +282,9 @@ sub _handle_error_response {
 sub _perform_request {
     my ($self, $request, $handlers) = @_;
 
-    $request->authorization_basic($self->{user}, $self->{password});
+    if ((defined $self->{user}) && (defined $self->{password})) {
+        $request->authorization_basic($self->{user}, $self->{password});
+    }
 
     if ($self->trace) {
         carp sprintf "request %s %s: %s",
@@ -646,7 +661,7 @@ If you do not supply a comment, the default value is "Issue closed by script".
 
 The $update_hash can be used to set or edit the values of other fields.
 
-The $operation paramter can be used to specify the closing transition type. This
+The $operation parameter can be used to specify the closing transition type. This
 can be useful when your JIRA configuration uses nonstandard or localized
 transition and status names, e.g.
 
@@ -772,7 +787,7 @@ errors => an arrayref containing error messages
 
 For example, to page through all results C<$max> at a time:
 
-    my (@all_results, $issues);
+    my (@all_results, @issues);
     do {
         $results = $self->search_issues($jql, $start, $max);
         if ($results->{errors}) {
@@ -781,7 +796,7 @@ For example, to page through all results C<$max> at a time:
         @issues = @{$results->{issues}};
         push @all_results, @issues;
         $start += $max;
-    } until (scalar(@$issues) < $max);
+    } until (scalar(@issues) < $max);
 
 (Or just use L</"all_search_results"> instead.)
 
@@ -929,7 +944,10 @@ on it and go directly to that issue.
 sub make_browse_url {
     my ($self, $key) = @_;
     # use url + browse + key to synthesize URL
-    return $self->{url} . 'browse/' . $key;
+    my $url = $self->{url};
+    $url =~ s/\/rest\/api\/.*//;
+    $url .= '/' unless $url =~ m{/$};
+    return $url . 'browse/' . $key;
 }
 
 =head2 get_link_types
@@ -1139,9 +1157,21 @@ Thanks very much to:
 
 =back
 
+=over 4
+
+=item Frank Schophuizen <Frank.Schophuizen@philips.com>
+
+=back
+
+=over 4
+
+=item Zhenyi Zhou <zhenyz@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Polyvore, Inc.
+This software is copyright (c) 2016 by Polyvore, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
